##
## objexport.py
## Writes the selected mesh to Wavefront OBJ.
## Copyright (C) 2002 MiKael NAVARRO
##
## This library is free software; you can redistribute it and/or
## modify it under the terms of the GNU Library General Public
## License as published by the Free Software Foundation; either
## version 2 of the License, or (at your option) any later version.
##
## This library is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## Library General Public License for more details.
##
## You should have received a copy of the GNU Library General Public
## License along with this library; if not, write to the
## Free Software Foundation, Inc., 59 Temple Place - Suite 330,
## Boston, MA  02111-1307, USA.
##

## Simple script writing the active object
## on disk (in Alias Wavefront OBJ format).

import Blender # Blender API
import sys
from Blender import NMesh, Object

# Get list of all selected objects
object = Object.GetSelected()
# Get active object
objname = object[0].getName()
# Low level mesh access
meshname = object[0].data.name
nmesh = NMesh.GetRaw(meshname)

filename = objname + ".obj"
file = open(filename, "w")
print "exporting %s ..." % objname

std = sys.stdout
sys.stdout = file

# Comments
print "# object", objname
print "# nb_vertices", len(nmesh.verts)
print "# nb_faces", len(nmesh.faces)
print

# Write object name (optional)
#print "o", objname
#print

# Get object size
sx, sy, sz = object[0].size

# Write vertices
for face in nmesh.faces:
  for vertex in face.v:
    print "v", vertex.co[0]*sx, vertex.co[1]*sy, vertex.co[2]*sz
print

# Write texcoords
if nmesh.hasFaceUV():
  for face in nmesh.faces:
    for uv in face.uv:
      print "vt", uv[0], uv[1]
  print
elif nmesh.hasVertexUV():
  for face in nmesh.faces:
    for vertex in face.v:
      print "vt", vertex.uvco[0], vertex.uvco[1]
  print

# Write normals
for face in nmesh.faces:
  for vertex in face.v:
    print "vn", vertex.no[0], vertex.no[1], vertex.no[2]
print

# Write group name (= objname)
print "g", objname
if nmesh.hasFaceUV() or nmesh.hasVertexUV():
  print "tex", nmesh.faces[0].image.name
print

# Write faces indexes
idx = 1
for face in nmesh.faces:
  print "f",
  for vertex in face.v:
    if nmesh.hasFaceUV() or nmesh.hasVertexUV():
      print "%d/%d/%d" % (idx, idx, idx) ,
    else:
      print "%d//%d" % (idx, idx) ,
    idx = idx + 1
  print

sys.stdout = std
file.close()

print "... saved to", filename

